.. _iris_whatsnew:

What's New in Iris
******************

These "What's new" pages describe the important changes between major
Iris versions.


.. toctree::
   :maxdepth: 1

   3.0.2.rst
   3.0.1.rst
   3.0.rst
   2.4.rst
   2.3.rst
   2.2.rst
   2.1.rst
   2.0.rst
   1.13.rst
   1.12.rst
   1.11.rst
   1.10.rst
   1.9.rst
   1.8.rst
   1.7.rst
   1.6.rst
   1.5.rst
   1.4.rst
   1.3.rst
   1.2.rst
   1.1.rst
   1.0.rst
